(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     29777,        719]
NotebookOptionsPosition[     27865,        678]
NotebookOutlinePosition[     28333,        697]
CellTagsIndexPosition[     28290,        694]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Peer To Peer Simulator", "Title",
 TextAlignment->Center,ExpressionUUID->"4508f2b5-b879-4e20-a3c6-eecc0f50d5bb"],

Cell["", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{
  Inherited, 3},ExpressionUUID->"370860a3-1eaa-468a-818c-9c15da36f625"],

Cell["\<\
You can interactively visualize the averaged annualized percentage return on \
a basket of peer to peer loans.  Select the mixture of loan grades to select \
in your basket of loans that you want to simulate. You can change the charge \
off multiplier to model when economic conditions get harder or easier.\
\>", "Text",ExpressionUUID->"15358b6b-724f-4715-81c1-142898e3f6c2"],

Cell["", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {10, 5}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{
  Inherited, 3},ExpressionUUID->"46792baa-98b3-4ea3-bb41-8718d68eb3b8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dynamic", "[", 
     RowBox[{"Panel", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"ValueQ", "@", "LoadStatus"}], ",", "LoadStatus", ",", 
         "\"\<Unloaded\>\""}], "]"}], ",", 
       RowBox[{"Background", "\[Rule]", 
        RowBox[{"Switch", "[", 
         RowBox[{
         "LoadStatus", ",", "\"\<Loaded\>\"", ",", "Green", ",", 
          "\"\<Loading\>\"", ",", "Orange", ",", "\"\<Unloaded\>\"", ",", 
          "LightRed"}], "]"}]}]}], "]"}], "]"}], ",", 
    RowBox[{"Dynamic", "[", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"Not", "@", 
        RowBox[{"ValueQ", "@", "LoadStatus"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"LoadStatus", "=", "\"\<Loading\>\""}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"packagePath", "=", 
         RowBox[{"File", "@", 
          RowBox[{"FileNameJoin", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"NotebookDirectory", "[", "]"}], ",", 
             "\"\<SimulateP2P.m\>\""}], "}"}], "]"}]}]}], ";", 
        RowBox[{"SessionSubmit", "[", 
         RowBox[{
          RowBox[{"Needs", "[", 
           RowBox[{"\"\<SimulateP2P`\>\"", ",", "packagePath"}], "]"}], ";", 
          RowBox[{"LoadStatus", "=", "\"\<Loaded\>\""}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\"\<\>\""}], ",", "\[IndentingNewLine]", 
       "\"\<\>\""}], "]"}], "]"}]}], "}"}], "]"}]], "Input",ExpressionUUID->\
"30b22fd1-235a-4566-9f2a-66e3423a5199"],

Cell[BoxData[
 TemplateBox[{DynamicBox[
    ToBoxes[
     Panel[
      If[
       ValueQ[$CellContext`LoadStatus], $CellContext`LoadStatus, "Unloaded"], 
      Background -> 
      Switch[$CellContext`LoadStatus, "Loaded", Green, "Loading", Orange, 
        "Unloaded", LightRed]], StandardForm]],DynamicBox[
    ToBoxes[
     If[
      Not[
       ValueQ[$CellContext`LoadStatus]], $CellContext`LoadStatus = 
       "Loading"; $CellContext`packagePath = File[
         FileNameJoin[{
           NotebookDirectory[], "SimulateP2P.m"}]]; 
      SessionSubmit[
       Needs["SimulateP2P`", $CellContext`packagePath]; \
$CellContext`LoadStatus = "Loaded"]; "", ""], StandardForm]]},
  "RowDefault"]], "Output",ExpressionUUID->"41121daf-d60b-4f1d-afe7-\
98f85a0f6f9f"]
}, {2}]],

Cell[CellGroupData[{

Cell["Construction", "Subsubsection",ExpressionUUID->"2b658a1a-b22f-488b-bc76-a6ab293200cc"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"grades", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<A\>\"", ",", "\"\<B\>\"", ",", "\"\<C\>\"", ",", "\"\<D\>\"", ",", 
     "\"\<E\>\"", ",", "\"\<F\>\""}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"colors", "=", 
    RowBox[{"{", 
     RowBox[{
     "Red", ",", "Orange", ",", "Yellow", ",", "Green", ",", "Blue", ",", 
      "Purple"}], "}"}]}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{"gradesPart", ":=", 
  RowBox[{"Grid", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"RawBoxes", "@", 
         RowBox[{"DynamicDump`togglerBarElement", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Dynamic", "[", "gradeSelection", "]"}], ",", "#", ",", 
             "#", ",", "##2"}], "}"}], ",", "StandardForm"}], "]"}]}], "&"}], 
       "[", 
       RowBox[{
        RowBox[{
         RowBox[{"grades", "[", 
          RowBox[{"[", "g", "]"}], "]"}], "<>", 
         RowBox[{"ToString", "[", "n", "]"}]}], ",", 
        RowBox[{"Background", "\[Rule]", 
         RowBox[{"colors", "[", 
          RowBox[{"[", "g", "]"}], "]"}]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"g", ",", "1", ",", 
        RowBox[{"Length", "[", "grades", "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"Spacings", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
       RowBox[{"FontColor", "\[Rule]", "White"}], ",", 
       RowBox[{"FontWeight", "\[Rule]", "Bold"}], ",", 
       RowBox[{"SetterBoxOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FrameMargins", "\[Rule]", "8"}], ",", 
          RowBox[{"Appearance", "\[Rule]", "\"\<Frameless\>\""}]}], "}"}]}]}],
       "}"}]}]}], "]"}]}]}], "Input",ExpressionUUID->"ea88d1eb-d5f0-46d8-9129-\
a43f262be73f"],

Cell[BoxData[
 RowBox[{"chargeOffPart", ":=", 
  RowBox[{"DynamicWrapper", "[", 
   RowBox[{
    RowBox[{"Row", "@", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Labeled", "[", 
        RowBox[{
         RowBox[{"Slider", "[", 
          RowBox[{
           RowBox[{"Dynamic", "[", "$ChargeOffMultiplier", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "3"}], "}"}]}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<ChargeOff Multipler\>\"", ",", 
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica Neue\>\""}]}], 
          "]"}], ",", "Top"}], "]"}], ",", 
       RowBox[{"Spacer", "[", "15", "]"}], ",", 
       RowBox[{"Dynamic", "[", "$ChargeOffMultiplier", "]"}]}], "}"}]}], ",", 
    "$ChargeOffMultiplier", ",", 
    RowBox[{"Initialization", "\[RuleDelayed]", 
     RowBox[{"(", 
      RowBox[{"$ChargeOffMultiplier", "=", "1.0"}], ")"}]}]}], 
   "]"}]}]], "Input",ExpressionUUID->"8e7b26c2-d4bd-4711-a73b-75a98e853624"],

Cell[BoxData[
 RowBox[{"runningPart", ":=", 
  RowBox[{"Grid", "[", 
   RowBox[{"{", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Labeled", "[", 
       RowBox[{
        RowBox[{"Checkbox", "[", 
         RowBox[{"Dynamic", "[", "running", "]"}], "]"}], ",", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Running\>\"", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica Neue\>\""}]}], 
         "]"}], ",", "Left"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Button", "[", 
       RowBox[{"\"\<reset\>\"", ",", 
        RowBox[{
         RowBox[{"LiveData", "=", " ", 
          RowBox[{"{", "}"}]}], ";", 
         RowBox[{"gradeSelection", "=", 
          RowBox[{"{", "}"}]}], ";", 
         RowBox[{"$ChargeOffMultiplier", "=", "1.0"}]}]}], "]"}]}], 
     "\[IndentingNewLine]", "}"}], "}"}], "]"}]}]], "Input",ExpressionUUID->\
"e6765714-546a-41b3-91cc-b405c0879fbd"],

Cell[BoxData[
 RowBox[{"histogramPart", ":=", 
  RowBox[{"DynamicModule", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"oldGradeSelection", ",", "oldChargeOffMultiplier"}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"DynamicWrapper", "[", 
     RowBox[{
      RowBox[{"Dynamic", "[", 
       RowBox[{"Histogram", "[", 
        RowBox[{
        "LiveData", ",", "100", ",", "\"\<ProbabilityDensity\>\"", ",", 
         RowBox[{"Axes", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"True", ",", "False"}], "}"}]}], ",", 
         RowBox[{"ImageSize", "\[Rule]", "550"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<Annualized Percentage Return\>\"", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica Neue\>\""}], ",", 
            " ", 
            RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}], "]"}], 
      ",", " ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"TrueQ", "[", "running", "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"oldGradeSelection", "=!=", "gradeSelection"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"LiveData", "=", " ", 
             RowBox[{"{", "}"}]}], ";", 
            RowBox[{
             RowBox[{"LocalSymbol", "[", "\"\<gradeSelection\>\"", "]"}], "=", 
             RowBox[{"oldGradeSelection", "=", "gradeSelection"}]}]}]}], 
          "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"oldChargeOffMultiplier", "=!=", "$ChargeOffMultiplier"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"LiveData", "=", " ", 
             RowBox[{"{", "}"}]}], ";", 
            RowBox[{
             RowBox[{
             "LocalSymbol", "[", "\"\<$ChargeOffMultiplier\>\"", "]"}], "=", 
             RowBox[{
             "oldChargeOffMultiplier", "=", "$ChargeOffMultiplier"}]}]}]}], 
          "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"gradeSelection", "=!=", 
            RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", " ", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"LiveData", ",", 
             RowBox[{
              RowBox[{"APR", "[", "3", "]"}], "[", 
              RowBox[{
               RowBox[{"TotalValue", "@", 
                RowBox[{"Nest", "[", 
                 RowBox[{"SimulateMonth", ",", 
                  RowBox[{"Basket", "[", 
                   RowBox[{"5000", ",", 
                    RowBox[{"{", "}"}], ",", "gradeSelection"}], "]"}], ",", 
                  "37"}], "]"}]}], "/", "5000"}], "]"}]}], "]"}]}], "]"}]}]}],
        "\[IndentingNewLine]", "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Initialization", "\[RuleDelayed]", 
     RowBox[{"(", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"LiveData", "=", 
        RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"gradeSelection", "=", 
        RowBox[{"LocalSymbol", "[", "\"\<gradeSelection\>\"", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"$ChargeOffMultiplier", "=", 
        RowBox[{"LocalSymbol", "[", "\"\<$ChargeOffMultiplier\>\"", "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"Not", "@", 
          RowBox[{"MatchQ", "[", 
           RowBox[{"LiveData", ",", "_List"}], "]"}]}], ",", 
         RowBox[{"LiveData", "=", 
          RowBox[{"{", "}"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"Not", "@", 
          RowBox[{"MatchQ", "[", 
           RowBox[{"$ChargeOffMultiplier", ",", "_Real"}], "]"}]}], ",", 
         RowBox[{"$ChargeOffMultiplier", "=", "1.0"}]}], "]"}], " ", ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"Not", "@", 
          RowBox[{"MatchQ", "[", 
           RowBox[{"gradeSelection", ",", "_List"}], "]"}]}], ",", 
         RowBox[{"gradeSelection", "=", 
          RowBox[{"{", "}"}]}]}], "]"}], " ", ";"}], "\[IndentingNewLine]", 
      ")"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",ExpressionUUID->\
"641b07c6-ac34-4fb9-95dc-f16f443e1f4e"]
}, Closed]],

Cell[CellGroupData[{

Cell["Interface", "Subsubsection",ExpressionUUID->"00bfbca0-5399-47f7-850a-f2da676fd7d8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CellPrint", "[", 
  RowBox[{"ExpressionCell", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Column", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{"gradesPart", ",", 
          RowBox[{"Spacer", "[", "15", "]"}], ",", 
          RowBox[{"Column", "[", 
           RowBox[{"{", 
            RowBox[{"chargeOffPart", ",", 
             RowBox[{"Spacer", "[", "10", "]"}], ",", "runningPart"}], "}"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Spacer", "[", "10", "]"}], ",", "histogramPart"}], "}"}], 
     "]"}], ",", "\"\<Output\>\"", ",", 
    RowBox[{"CellMargins", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"10", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "10"}], "}"}]}], "}"}]}]}], "]"}], "]"}]], "Input",\
ExpressionUUID->"1055b3cc-5bf4-40cd-9f95-2e42f43bdb91"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{TagBox[
        GridBox[{{
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "A1"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "A1"]& ], {True}, "\"A1\"", Background -> RGBColor[1, 0, 0]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "B1"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "B1"]& ], {True}, "\"B1\"", Background -> RGBColor[1, 0.5, 0]], 
           
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "C1"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "C1"]& ], {True}, "\"C1\"", Background -> RGBColor[1, 1, 0]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "D1"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "D1"]& ], {True}, "\"D1\"", Background -> RGBColor[0, 1, 0]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "E1"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "E1"]& ], {True}, "\"E1\"", Background -> RGBColor[0, 0, 1]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "F1"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "F1"]& ], {True}, "\"F1\"", Background -> 
            RGBColor[0.5, 0, 0.5]]}, {
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "A2"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "A2"]& ], {True}, "\"A2\"", Background -> RGBColor[1, 0, 0]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "B2"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "B2"]& ], {True}, "\"B2\"", Background -> RGBColor[1, 0.5, 0]], 
           
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "C2"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "C2"]& ], {True}, "\"C2\"", Background -> RGBColor[1, 1, 0]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "D2"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "D2"]& ], {True}, "\"D2\"", Background -> RGBColor[0, 1, 0]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "E2"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "E2"]& ], {True}, "\"E2\"", Background -> RGBColor[0, 0, 1]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "F2"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "F2"]& ], {True}, "\"F2\"", Background -> 
            RGBColor[0.5, 0, 0.5]]}, {
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "A3"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "A3"]& ], {True}, "\"A3\"", Background -> RGBColor[1, 0, 0]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "B3"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "B3"]& ], {True}, "\"B3\"", Background -> RGBColor[1, 0.5, 0]], 
           
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "C3"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "C3"]& ], {True}, "\"C3\"", Background -> RGBColor[1, 1, 0]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "D3"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "D3"]& ], {True}, "\"D3\"", Background -> RGBColor[0, 1, 0]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "E3"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "E3"]& ], {True}, "\"E3\"", Background -> RGBColor[0, 0, 1]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "F3"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "F3"]& ], {True}, "\"F3\"", Background -> 
            RGBColor[0.5, 0, 0.5]]}, {
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "A4"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "A4"]& ], {True}, "\"A4\"", Background -> RGBColor[1, 0, 0]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "B4"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "B4"]& ], {True}, "\"B4\"", Background -> RGBColor[1, 0.5, 0]], 
           
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "C4"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "C4"]& ], {True}, "\"C4\"", Background -> RGBColor[1, 1, 0]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "D4"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "D4"]& ], {True}, "\"D4\"", Background -> RGBColor[0, 1, 0]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "E4"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "E4"]& ], {True}, "\"E4\"", Background -> RGBColor[0, 0, 1]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "F4"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "F4"]& ], {True}, "\"F4\"", Background -> 
            RGBColor[0.5, 0, 0.5]]}, {
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "A5"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "A5"]& ], {True}, "\"A5\"", Background -> RGBColor[1, 0, 0]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "B5"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "B5"]& ], {True}, "\"B5\"", Background -> RGBColor[1, 0.5, 0]], 
           
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "C5"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "C5"]& ], {True}, "\"C5\"", Background -> RGBColor[1, 1, 0]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "D5"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "D5"]& ], {True}, "\"D5\"", Background -> RGBColor[0, 1, 0]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "E5"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "E5"]& ], {True}, "\"E5\"", Background -> RGBColor[0, 0, 1]], 
           SetterBox[
            Dynamic[
             MemberQ[$CellContext`gradeSelection, "F5"], 
             BoxForm`TogglerBarFunction[$CellContext`gradeSelection, 
              "F5"]& ], {True}, "\"F5\"", Background -> 
            RGBColor[0.5, 0, 0.5]]}}, AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{0}}}, 
         BaseStyle -> {
          FontFamily -> "Helvetica", FontSize -> 16, FontColor -> 
           GrayLevel[1], FontWeight -> Bold, 
           SetterBoxOptions -> {
            FrameMargins -> 8, Appearance -> "Frameless"}}], "Grid"],
       TemplateBox[{15}, "Spacer1"],TagBox[
        GridBox[{{
           DynamicWrapperBox[
            TemplateBox[{
              TemplateBox[{
                SliderBox[
                 Dynamic[SimulateP2P`$ChargeOffMultiplier], {0, 3}], 
                StyleBox[
                "\"ChargeOff Multipler\"", FontFamily -> "Helvetica Neue", 
                 StripOnInput -> False]}, "Labeled", 
               DisplayFunction -> (GridBox[{{
                   ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
                   TagBox[
                    ItemBox[
                    PaneBox[
                    TagBox[#, "SkipImageSizeLevel"], 
                    Alignment -> {Center, Baseline}, BaselinePosition -> 
                    Baseline], DefaultBaseStyle -> "Labeled"], 
                    "SkipImageSizeLevel"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Center}}, "Rows" -> {{Center}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaselinePosition -> {2, 1}]& ), 
               InterpretationFunction -> (RowBox[{"Labeled", "[", 
                  RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
              TemplateBox[{15}, "Spacer1"], 
              DynamicBox[
               ToBoxes[SimulateP2P`$ChargeOffMultiplier, StandardForm]]}, 
             "RowDefault"], SimulateP2P`$ChargeOffMultiplier, 
            Initialization :> (SimulateP2P`$ChargeOffMultiplier = 1.)]}, {
           TemplateBox[{10}, "Spacer1"]}, {
           TagBox[
            GridBox[{{
               TemplateBox[{
                 CheckboxBox[
                  Dynamic[$CellContext`running]], 
                 StyleBox[
                 "\"Running\"", FontFamily -> "Helvetica Neue", StripOnInput -> 
                  False]}, "Labeled", DisplayFunction -> (GridBox[{{
                    ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
                    TagBox[
                    ItemBox[
                    PaneBox[
                    TagBox[#, "SkipImageSizeLevel"], 
                    Alignment -> {Center, Baseline}, BaselinePosition -> 
                    Baseline], DefaultBaseStyle -> "Labeled"], 
                    "SkipImageSizeLevel"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Center}}, "Rows" -> {{Center}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  BaselinePosition -> {1, 2}]& ), 
                InterpretationFunction -> (RowBox[{"Labeled", "[", 
                   RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )], 
               ButtonBox[
               "\"reset\"", 
                ButtonFunction :> ($CellContext`LiveData = {}; \
$CellContext`gradeSelection = {}; SimulateP2P`$ChargeOffMultiplier = 1.), 
                Appearance -> Automatic, Evaluator -> Automatic, Method -> 
                "Preemptive"]}}, AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
            "Grid"]}}, GridBoxAlignment -> {"Columns" -> {{Left}}}, 
         DefaultBaseStyle -> "Column", 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"]},
      "RowDefault"]},
    {
     TemplateBox[{10},
      "Spacer1"]},
    {
     DynamicModuleBox[{$CellContext`oldGradeSelection$$ = {
      "C4", "B5"}, $CellContext`oldChargeOffMultiplier$$ = 
      0.9500000000000001}, 
      DynamicWrapperBox[
       DynamicBox[ToBoxes[
         Histogram[$CellContext`LiveData, 100, "ProbabilityDensity", 
          Axes -> {True, False}, ImageSize -> 550, PlotLabel -> 
          Style["Annualized Percentage Return", FontFamily -> 
            "Helvetica Neue", FontSize -> 14]], StandardForm],
        ImageSizeCache->{550., {181., 185.}}], If[
        TrueQ[$CellContext`running], 
        If[$CellContext`oldGradeSelection$$ =!= $CellContext`gradeSelection, \
$CellContext`LiveData = {}; 
          LocalSymbol[
            "gradeSelection"] = ($CellContext`oldGradeSelection$$ = \
$CellContext`gradeSelection)]; 
        If[$CellContext`oldChargeOffMultiplier$$ =!= 
          SimulateP2P`$ChargeOffMultiplier, $CellContext`LiveData = {}; 
          LocalSymbol[
            "$ChargeOffMultiplier"] = ($CellContext`oldChargeOffMultiplier$$ = 
            SimulateP2P`$ChargeOffMultiplier)]; 
        If[$CellContext`gradeSelection =!= {}, 
          AppendTo[$CellContext`LiveData, 
           SimulateP2P`APR[3][SimulateP2P`TotalValue[
              Nest[SimulateP2P`SimulateMonth, 
               SimulateP2P`Basket[5000, {}, $CellContext`gradeSelection], 
               37]]/5000]]]],
       ImageSizeCache->{550., {181., 185.}}],
      DynamicModuleValues:>{},
      Initialization:>($CellContext`LiveData = {}; \
$CellContext`gradeSelection = LocalSymbol["gradeSelection"]; 
       SimulateP2P`$ChargeOffMultiplier = LocalSymbol["$ChargeOffMultiplier"]; 
       If[
         Not[
          MatchQ[$CellContext`LiveData, 
           Blank[List]]], $CellContext`LiveData = {}]; If[
         Not[
          MatchQ[SimulateP2P`$ChargeOffMultiplier, 
           Blank[Real]]], SimulateP2P`$ChargeOffMultiplier = 1.]; If[
         Not[
          MatchQ[$CellContext`gradeSelection, 
           Blank[List]]], $CellContext`gradeSelection = {}]; Null)]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellMargins->{{10, 10}, {10, 
  10}},ExpressionUUID->"dcfecbd4-e57d-432a-9a06-d1dbb9056f09"]
}, {2}]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",ExpressionUUID->\
"6c45351c-c034-401f-8a2c-b558fd718a68"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{925, 936},
WindowMargins->{{282, Automatic}, {Automatic, 20}},
ShowCellBracket->False,
LinebreakSemicolonWeighting->"Normal",
Background->RGBColor[0.914137, 0.964538, 1],
FrontEndVersion->"11.2 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
10, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 118, 1, 98, "Title",ExpressionUUID->"4508f2b5-b879-4e20-a3c6-eecc0f50d5bb"],
Cell[701, 25, 330, 10, 6, "Text",ExpressionUUID->"370860a3-1eaa-468a-818c-9c15da36f625"],
Cell[1034, 37, 386, 5, 81, "Text",ExpressionUUID->"15358b6b-724f-4715-81c1-142898e3f6c2"],
Cell[1423, 44, 331, 10, 19, "Text",ExpressionUUID->"46792baa-98b3-4ea3-bb41-8718d68eb3b8"],
Cell[CellGroupData[{
Cell[1779, 58, 1578, 39, 199, "Input",ExpressionUUID->"30b22fd1-235a-4566-9f2a-66e3423a5199"],
Cell[3360, 99, 764, 20, 50, "Output",ExpressionUUID->"41121daf-d60b-4f1d-afe7-98f85a0f6f9f"]
}, {2}]],
Cell[CellGroupData[{
Cell[4158, 124, 92, 0, 45, "Subsubsection",ExpressionUUID->"2b658a1a-b22f-488b-bc76-a6ab293200cc"],
Cell[4253, 126, 2132, 58, 220, "Input",ExpressionUUID->"ea88d1eb-d5f0-46d8-9129-a43f262be73f"],
Cell[6388, 186, 985, 24, 115, "Input",ExpressionUUID->"8e7b26c2-d4bd-4711-a73b-75a98e853624"],
Cell[7376, 212, 928, 23, 94, "Input",ExpressionUUID->"e6765714-546a-41b3-91cc-b405c0879fbd"],
Cell[8307, 237, 4339, 102, 472, "Input",ExpressionUUID->"641b07c6-ac34-4fb9-95dc-f16f443e1f4e"]
}, Closed]],
Cell[CellGroupData[{
Cell[12683, 344, 89, 0, 37, "Subsubsection",ExpressionUUID->"00bfbca0-5399-47f7-850a-f2da676fd7d8"],
Cell[CellGroupData[{
Cell[12797, 348, 947, 25, 73, "Input",ExpressionUUID->"1055b3cc-5bf4-40cd-9f95-2e42f43bdb91"],
Cell[13747, 375, 13869, 293, 576, "Output",ExpressionUUID->"dcfecbd4-e57d-432a-9a06-d1dbb9056f09"]
}, {2}]],
Cell[27628, 671, 209, 3, 136, "Input",ExpressionUUID->"6c45351c-c034-401f-8a2c-b558fd718a68"]
}, Open  ]]
}, Open  ]]
}
]
*)

